@@ -8,11 +8,11 @@ Rubric::WebApp - the web interface to Rubric
 
 =head1 VERSION
 
-version 0.148
+version 0.149
 
 =cut
 
-our $VERSION = '0.148';
+our $VERSION = '0.149';
 
 =head1 SYNOPSIS
 
@@ -1002,11 +1002,13 @@ sub _post_form_contents {
     for qw(entryid uri title description tags body);
 
   for (qw(uri title description body tags)) {
+    my $decoded;
     my $ok = eval {
-      decode_utf8($form{$_}, Encode::FB_CROAK | Encode::LEAVE_SRC);
+      $decoded = decode_utf8($form{$_}, Encode::FB_CROAK | Encode::LEAVE_SRC);
       1;
     };
-    $error{$_} = "Invalid UTF-8 characters in $_." unless $ok;
+    $error{$_} = "Invalid characters in $_." unless $ok;
+    $form{$_} = $decoded if $ok;
   }
 
   eval { $form{uri} = URI->new($form{uri})->canonical; };
